@@ -1,4 +1,6 @@
+from idecomp.config import SUBSISTEMAS
 from typing import Dict, List
+from copy import deepcopy
 import numpy as np  # type: ignore
 
 
@@ -239,7 +241,7 @@ class ENAPreEstudoSemanalSubsistemaRelato:
 
     def __eq__(self, o: object) -> bool:
         """
-        A igualdade entre ENAPreEstudoSemanalRelato
+        A igualdade entre BalancoEnergeticoRelato
         avalia todos os campos.
         """
         if not isinstance(o, ENAPreEstudoSemanalSubsistemaRelato):
@@ -293,6 +295,174 @@ class ENAPreEstudoSemanalSubsistemaRelato:
         return dict_earm
 
 
+class BalancoEnergeticoRelato:
+    """
+    Armazena os dados de saída existentes no relato do DECOMP
+    referentes ao balanço energético para o primeiro mês.
+
+    Esta classe armazena as tabelas do balanço por subsistema
+    em cada patamar de carga e os valores médios.
+
+    **Parâmetros**
+
+    - subsistema: `List[str]`
+    - tabela: `np.ndarray`
+
+    """
+    def __init__(self,
+                 subsistema: List[str],
+                 tabela: np.ndarray):
+        self.subsistema = subsistema
+        self.tabela = tabela
+
+    def __eq__(self, o: object) -> bool:
+        """
+        A igualdade entre ENAPreEstudoSemanalRelato
+        avalia todos os campos.
+        """
+        if not isinstance(o, BalancoEnergeticoRelato):
+            return False
+        bal: BalancoEnergeticoRelato = o
+        eq_subsistema = self.subsistema == bal.subsistema
+        eq_tabela = np.array_equal(self.tabela, bal.tabela)
+        return all([eq_subsistema, eq_tabela])
+
+    @property
+    def mercado_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Mercado médio por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        col_merc = 0
+        dict_merc: Dict[str, np.ndarray] = {}
+        for i, sub in enumerate(SUBSISTEMAS):
+            dict_merc[sub] = self.tabela[:, i, col_merc]
+        return dict_merc
+
+    @property
+    def bacia_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Bacia média por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        col_bacia = 1
+        dict_bacia: Dict[str, np.ndarray] = {}
+        for i, sub in enumerate(SUBSISTEMAS):
+            dict_bacia[sub] = self.tabela[:, i, col_bacia]
+        return dict_bacia
+
+    @property
+    def cbomba_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Cbomba médio por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        col_cbomba = 2
+        dict_cbomba: Dict[str, np.ndarray] = {}
+        for i, sub in enumerate(SUBSISTEMAS):
+            dict_cbomba[sub] = self.tabela[:, i, col_cbomba]
+        return dict_cbomba
+
+    @property
+    def geracao_hidraulica_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Geração Hidráulica (Ghid) médio por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        col_ghid = 3
+        dict_ghid: Dict[str, np.ndarray] = {}
+        for i, sub in enumerate(SUBSISTEMAS):
+            ghid = deepcopy(self.tabela[:, i, col_ghid])
+            ghid += self.tabela[:, i, 15]
+            ghid += self.tabela[:, i, 16]
+            dict_ghid[sub] = ghid
+        return dict_ghid
+
+    @property
+    def geracao_termica_antecipada_subsistema(self) -> Dict[str,
+                                                            np.ndarray]:
+        """
+        Geração térmica antecipada média por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        col_gterat = 5
+        dict_gterat: Dict[str, np.ndarray] = {}
+        for i, sub in enumerate(SUBSISTEMAS):
+            dict_gterat[sub] = self.tabela[:, i, col_gterat]
+        return dict_gterat
+
+    @property
+    def deficit_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Déficit médio por subsistema e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        col_def = 6
+        dict_def: Dict[str, np.ndarray] = {}
+        for i, sub in enumerate(SUBSISTEMAS):
+            dict_def[sub] = self.tabela[:, i, col_def]
+        return dict_def
+
+
 class Relato:
     """
     Armazena os dados de saída do DECOMP referentes ao
@@ -312,6 +482,7 @@ class Relato:
     - geracao_termica_subsistema: `GeracaoTermicaSubsistemaRelato`
     - earm_subsistema: `EnergiaArmazenadaSubsistemaRelato`
     - ena_pre_semanal: `ENAPreEstudoSemanalSubsistemaRelato`
+    - balanco_energetico: `BalancoEnergeticoRelato`
 
     """
     def __init__(self,
@@ -319,12 +490,14 @@ class Relato:
                  cmo: CMORelato,
                  geracao_termica_subsistema: GeracaoTermicaSubsistemaRelato,
                  earm_subsistema: EnergiaArmazenadaSubsistemaRelato,
-                 ena_pre_sem_subsistema: ENAPreEstudoSemanalSubsistemaRelato):
+                 ena_pre_sem_subsistema: ENAPreEstudoSemanalSubsistemaRelato,
+                 balanco_energetico: BalancoEnergeticoRelato):
         self.dados_gerais = dados_gerais
         self._cmo = cmo
         self._geracao_termica_subsistema = geracao_termica_subsistema
         self._earm_subsistema = earm_subsistema
         self._ena_pre_semanal_subsistema = ena_pre_sem_subsistema
+        self.balanco_energetico = balanco_energetico
 
     def __eq__(self, o: object) -> bool:
         """
@@ -454,3 +627,111 @@ class Relato:
         ena = (self._ena_pre_semanal_subsistema.
                energia_afluente_pre_estudo_semanal)
         return ena
+
+    @property
+    def mercado_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Mercado médio por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        return self.balanco_energetico.mercado_subsistema
+
+    @property
+    def bacia_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Bacia média por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        return self.balanco_energetico.bacia_subsistema
+
+    @property
+    def cbomba_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Cbomba médio por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        return self.balanco_energetico.cbomba_subsistema
+
+    @property
+    def geracao_hidraulica_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Geração Hidráulica (Ghid) médio por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        return self.balanco_energetico.geracao_hidraulica_subsistema
+
+    @property
+    def geracao_termica_antecipada_subsistema(self) -> Dict[str,
+                                                            np.ndarray]:
+        """
+        Geração térmica antecipada média por subsistema
+        e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        return self.balanco_energetico.geracao_termica_antecipada_subsistema
+
+    @property
+    def deficit_subsistema(self) -> Dict[str, np.ndarray]:
+        """
+        Déficit médio por subsistema e por semana, em MWmed.
+
+        **Retorna**
+
+        `Dict[str, np.ndarray]`
+
+        **Sobre**
+
+        O acesso é feito com `[subsistema]` e é retornada um
+        array onde a posição [i - 1] contém os dados do período
+        i do DECOMP.
+        """
+        return self.balanco_energetico.deficit_subsistema
